================
Group
================

SWAN group commands

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.group.BaseGroupComponent
   rompy_swan.components.group.STARTUP
   rompy_swan.components.group.INPGRIDS
   rompy_swan.components.group.PHYSICS
   rompy_swan.components.group.OUTPUT
   rompy_swan.components.group.LOCKUP